/* ============================== */
/* Zeta import: 'zeta://z/z-reset/z-reset.css' */
/* From: 'None' */
/* http://meyerweb.com/eric/tools/css/reset/ 
   v2.0 | 20110126
   License: none (public domain)
*/

html, body, div, span, applet, object, iframe,
h1, h2, h3, h4, h5, h6, p, blockquote, pre,
a, abbr, acronym, address, big, cite, code,
del, dfn, em, img, ins, kbd, q, s, samp,
small, strike, strong, sub, sup, tt, var,
b, u, i, center,
dl, dt, dd, ol, ul, li,
fieldset, form, label, legend,
table, caption, tbody, tfoot, thead, tr, th, td,
article, aside, canvas, details, embed, 
figure, figcaption, footer, header, hgroup, 
menu, nav, output, ruby, section, summary,
time, mark, audio, video {
	margin: 0;
	padding: 0;
	border: 0;
	font-size: 100%;
	font: inherit;
	vertical-align: baseline;
}
/* HTML5 display-role reset for older browsers */
article, aside, details, figcaption, figure, 
footer, header, hgroup, menu, nav, section {
	display: block;
}
body {
	line-height: 1;
}
ol, ul {
	list-style: none;
}
blockquote, q {
	quotes: none;
}
blockquote:before, blockquote:after,
q:before, q:after {
	content: '';
	content: none;
}
table {
	border-collapse: collapse;
	border-spacing: 0;
}


/* ============================== */
/* Zeta import: 'zeta://z/z-base/z-base.scss' */
/* From: 'zeta://z/z-reset/z-reset.css' */
/* fonts.css from the YUI Library: developer.yahoo.com/yui/
   refer to developer.yahoo.com/yui/3/cssfonts/ for font sizing percentages */ 

body {
	*font-size: small;
	font: 13px/1.231 sans-serif}

select, input, textarea, button {
	font: 99% sans-serif}

pre, code, kbd, samp {
	font-family: monospace, sans-serif}

body, select, input, textarea {
	color: #444;
	font-family: Georgia, serif}

h1, h2, h3, h4, h5, h6 {
	font-weight: bold}

html {
	overflow-y: scroll}

a:hover, a:active {
	outline: none}

a, a:active, a:visited {
	color: #607890}

a:hover {
	color: #036}

ul, ol {
	margin-left: 1.8em}

ol {
	list-style-type: decimal}

nav ul, nav li {
	margin: 0}

small {
	font-size: 85%}

strong, th {
	font-weight: bold}

td, td img {
	vertical-align: top}

sub, sup {
	font-size: 75%;
	line-height: 0;
	position: relative}

sup {
	top: -0.5em}

sub {
	bottom: -0.25em}

pre {
	padding: 15px;
	white-space: pre;
	white-space: pre-wrap;
	white-space: pre-line;
	word-wrap: break-word}

textarea {
	overflow: auto}

input[type="radio"] {
	vertical-align: text-bottom}

input[type="checkbox"] {
	vertical-align: bottom}

.ie7 input[type="checkbox"] {
	vertical-align: baseline}

.ie6 input {
	vertical-align: text-bottom}

label, input[type="button"], input[type="submit"], input[type="image"], button {
	cursor: pointer}

button, input, select, textarea {
	margin: 0}
/* colors for form validity */ 

input:invalid, textarea:invalid {
	-moz-box-shadow: 0px 0px 5px red;
	-webkit-box-shadow: 0px 0px 5px red;
	border-radius: 1px;
	box-shadow: 0px 0px 5px red}

.no-boxshadow input:invalid, .no-boxshadow textarea:invalid {
	background-color: red}

::-moz-selection {
	background: #ff5e99;
	color: #fff;
	text-shadow: none}

::selection {
	background: #ff5e99;
	color: #fff;
	text-shadow: none}

a:link {
	-webkit-tap-highlight-color: #ff5e99}

button {
	overflow: visible;
	width: auto}


/* ============================== */
/* Zeta import: 'zeta://z/z-typography/z-typography.css' */
/* From: 'zeta://z/z-base/z-base.scss' */
h1 {
	font-size: 3em;
	line-height: 1;
	margin-bottom: 0.5em}

h2 {
	font-size: 2em;
	margin-bottom: 0.75em}

h3 {
	font-size: 1.5em;
	line-height: 1;
	margin-bottom: 1em}

h4 {
	font-size: 1.2em;
	line-height: 1.25;
	margin-bottom: 1.25em}

h5 {
	font-size: 1em;
	font-weight: bold;
	margin-bottom: 1.5em}

h6 {
	font-size: 1em;
	font-weight: bold}

h1 img, h2 img, h3 img, h4 img, h5 img, h6 img {
	margin: 0}

p {
	margin: 0 0 1.5em}

blockquote {
	color: #666;
	font-style: italic;
	margin: 1.5em}

strong, dfn {
	font-weight: bold}

em, dfn {
	font-style: italic}

sup, sub {
	line-height: 0}

abbr, acronym {
	border-bottom: 1px dotted #666}

address {
	font-style: italic;
	margin: 0 0 1.5em}


/* ============================== */
/* Zeta import: 'zeta://z/z-grid/z-grid.scss' */
/* From: 'zeta://z/z-typography/z-typography.css' */
.z-grid-1 {
	width: 60px}

.z-grid-2 {
	width: 140px}

.z-grid-3 {
	width: 220px}

.z-grid-4 {
	width: 300px}

.z-grid-5 {
	width: 380px}

.z-grid-6 {
	width: 460px}

.z-grid-7 {
	width: 540px}

.z-grid-8 {
	width: 620px}

.z-grid-9 {
	width: 700px}

.z-grid-10 {
	width: 780px}

.z-grid-11 {
	width: 860px}

.z-grid-12 {
	width: 940px}

.z-grid_table {
	margin: 0 auto;
	overflow: hidden;
	width: 960px;
	zoom: 1}

.z-grid_column {
	display: inline;
	float: left;
	margin: 0 10px;
	overflow: hidden;
	zoom: 1}

.z-grid_row {
	display: inline-block;
	margin: 0 -10px;
	width: auto}


/* ============================== */
/* Zeta import: '/home/klen/Projects/github.com/zeta-library/zetalibrary/tests/zeta/test_helpers.scss' */
/* From: 'zeta://z/z-grid/z-grid.scss' */
.test {
	-moz-text-shadow: 2px 2px 2px rgba(10, 10, 10, .45);
	-o-text-shadow: 2px 2px 2px rgba(10, 10, 10, .45);
	-webkit-text-shadow: 2px 2px 2px rgba(10, 10, 10, .45);
	background-repeat: no-repeat;
	direction: ltr;
	display: block;
	display: inline;
	float: left;
	overflow: hidden;
	overflow: hidden;
	text-align: left;
	text-indent: -999em;
	text-shadow: 2px 2px 2px rgba(10, 10, 10, .45);
	zoom: 1}

.test_center {
	display: block;
	margin-left: auto;
	margin-right: auto}

.test_center_round {
	-moz-border-radius: 3px 3px;
	-moz-box-shadow: 3px 4px 3px 1px rgba(10, 10, 10, .45);
	-o-border-radius: 3px 3px;
	-o-box-shadow: 3px 4px 3px 1px rgba(10, 10, 10, .45);
	-webkit-border-radius: 3px 3px;
	-webkit-box-shadow: 3px 4px 3px 1px rgba(10, 10, 10, .45);
	border-radius: 3px 3px;
	box-shadow: 3px 4px 3px 1px rgba(10, 10, 10, .45)}


