/* ============================== */
/* Zeta import: 'zeta://f/compass/reset.scss' */
/* From: 'None' */
html, body, div, span, applet, object, iframe, h1, h2, h3, h4, h5, h6, p, blockquote, pre, a, abbr, acronym, address, big, cite, code, del, dfn, em, font, img, ins, kbd, q, s, samp, small, strike, strong, sub, sup, tt, var, dl, dt, dd, ol, ul, li, fieldset, form, label, legend, table, caption, tbody, tfoot, thead, tr, th, td {
	border: 0;
	font-family: inherit;
	font-size: 100%;
	font-style: inherit;
	font-weight: inherit;
	margin: 0;
	outline: 0;
	padding: 0;
	vertical-align: baseline}

body {
	background: white;
	color: black;
	line-height: 1}

ol, ul {
	list-style: none}

table {
	border-collapse: separate;
	border-spacing: 0;
	vertical-align: middle}

caption, th, td {
	font-weight: normal;
	text-align: left;
	vertical-align: middle}

q, blockquote {
	quotes: "" ""}

q:before, q:after, blockquote:before, blockquote:after {
	content: ""}

a img {
	border: none}


/* ============================== */
/* Zeta import: 'zeta://f/compass.css' */
/* From: 'zeta://f/compass/reset.scss' */
/* 
Compass is a stylesheet authoring framework. See: http://compass-style.org/ 

 */


