@import url(typography.scss);

@mixin blueprint-print {
    body {
        @include blueprint-print-body; }

    @include blueprint-print-defaults; }

@mixin blueprint-show-link-urls {
    &:after {
        content: " (" attr(href) ")";
        font-size: 90%; } }

@mixin blueprint-print-body {
    line-height: 1.5;
    font-family: $blueprint_font_family;
    color: black;
    background: none;
    font-size: 10pt; }

@mixin blueprint-print-defaults {
    .container {
        background: none; }
    hr {
        background: #cccccc;
        color: #cccccc;
        width: 100%;
        height: 2px;
        margin: 2em 0;
        padding: 0;
        border: none;
        &.space {
            background: white;
            color: white; } }

    h1, h2, h3, h4, h5, h6 {
        font-family: $blueprint_font_family; }

    code {
        font: {
            size: 0.9em;
            family: $blueprint_fixed_font_family; }; }

    a {
        img {
            border: none; }
        &:link, &:visited {
            background: transparent;
            font-weight: 700;
            text-decoration: underline; } }

    p img.top {
        margin-top: 0; }

    blockquote {
        margin: 1.5em;
        padding: 1em;
        font-style: italic;
        font-size: 0.9em; }

    .small {
        font-size: 0.9em; }

    .large {
        font-size: 1.1em; }

    .quiet {
        color: #999999; }

    .hide {
        display: none; } }
