$font_color:     #333333 !default;
$quiet_color:    $font_color + #333333 !default;
$loud_color:     $font_color - #222222 !default;
$header_color:   $font_color - #111111 !default;
$alt_text_color: #666666 !default;
$blueprint_background_color: #eeeeee !default;

$link_color:         #000099               !default;
$link_hover_color:   black                 !default;
$link_focus_color:   $link_hover_color     !default;
$link_active_color:  $link_color + #cc0000 !default;
$link_visited_color: $link_color - #333333 !default;

$feedback_border_color: #dddddd !default;
$success_color:         #264409 !default;
$success_bg_color:      #e6efc2 !default;
$success_border_color:  #c6d880 !default;
$notice_color:          #514721 !default;
$notice_bg_color:       #fff6bf !default;
$notice_border_color:   #ffd324 !default;
$error_color:           #8a1f11 !default;
$error_bg_color:        #fbe3e4 !default;
$error_border_color:    #fbc2c4 !default;

$highlight_color:        yellow !default;
$added_color:             white !default;
$added_bg_color:        #006600 !default;
$removed_color:           white !default;
$removed_bg_color:      #990000 !default;

$blueprint_table_header_color: #c3d9ff !default;
$blueprint_table_stripe_color: #e5ecf9 !default;
